import React from 'react';
import { Router, Route, Switch } from 'dva/router';
import zhCN from 'antd/es/locale/zh_CN';
import styles from './style.module.less';
import { ConfigProvider, Layout } from 'antd';
import dva, { connect } from 'dva';
import { createBrowserHistory as createHistory } from 'history';
import Component from 'Component';
import propsConfig from 'Component/src/props.config.js';
import componentPackage from 'Component/package.json';
import Theme from '@icode-run/theme';
import themePropsConfig from '@icode-run/theme/src/props.config.js';
import themePackage from '@icode-run/theme/package.json';
const { Header } = Layout;
import defaultTheme from '@icode-run/default-theme';

import importRemote, {setRemoteConfig} from 'import-remote-module';
setRemoteConfig({
  icodeModules: 'https://www.icoderun.com/modules/remoteEntry.js?v='+(+new Date())
})
const MyDesigner = importRemote('icodeModules/Designer');

import request from '@/utils/request';
const tokenData = request({
  method: 'POST',
  url: 'https://www.icoderun.com/lowcodeApi/accessToken/getToken',
  type: 'json',
  body: {
    appId: 'component435433212334',
  },
}).then(tokenData => {
  const propsConfigs = {
    [componentPackage.name]: {
      type: "element",
      component: 'Component',
      name: propsConfig.name,
      config: {
        packageInfo: {
          name: propsConfig.name,
          packageName: componentPackage.name,
          type: "element",
          component: 'Component',
          remoteAppName: '',
          remoteEntryPath: '',
        },
        ...propsConfig
      }
    },
    [themePackage.name]: {
      type: "element",
      component: 'Theme',
      name: themePropsConfig.name,
      config: {
        packageInfo: {
          name: themePropsConfig.name,
          packageName: themePackage.name,
          type: "element",
          component: 'Theme',
          remoteAppName: '',
          remoteEntryPath: '',
        },
        ...themePropsConfig
      }
    },
  }
  
  const importComponents = {
    [componentPackage.name]: Component,
    [themePackage.name]: Theme
  }
  
  const theme = {
    ...defaultTheme.light,
    themeMode: "light",
  }
  
  const app = dva({
    history: createHistory(),
  });
  app.router(history => {
  //  const location = history.history.location;
    return (
      <Router history={history.history}>
          <Switch>
            <Route
              key={'/sdff'}
              path={'/'}
              render={() => {
                return (
                  <ConfigProvider locale={zhCN}>
                    <Header className={styles.header} theme="dark">
                      <a onClick={() => {
                          history.push('/');
                        }}>
                      <div className={styles.logo}></div>
                      </a>
                    </Header>
                    {<MyDesigner
                      connect={connect}
                      app={app}
                      token={tokenData.data}
                      importComponents={importComponents}
                      componentDefaultConfigs={propsConfigs}
                      componentList={[]}
                      //  dataModels={null}
                      singleComponentName={componentPackage.name}
                      //  componentConfig={null}
                      globalState={theme}
  
                      key={'designer}'}
                      designer={'designer'} /> }
                  </ConfigProvider>
                );
              }}
            />
          </Switch>
      </Router>
    );
  });
   
  // 5. Start
  app.start('#component-layout-root');
});


 