//import { message } from 'antd';
import axios from 'axios';
import { get, isObject, upperFirst } from 'lodash';
import qs from 'qs';

axios.create({
  timeout: 10000,
  headers: { 'X-Requested-With': 'XMLHttpRequest' },
});

const trimParams = params => {
  if (isObject(params) && !Array.isArray(params)) {
    Object.keys(params).forEach(key => {
      if (typeof params[key] === 'string') {
        params[key] = params[key].replace(/(^\s+)|(\s+$)/g, '');
      }
    });
  } else if (typeof params === 'string' && params.indexOf('=') > 0) {
    const newParams = qs.parse(params);
    params = trimParams(newParams);
    params = qs.stringify(params);
  }
  return params;
};

const parseData = (res) => {
  if(res.result === 'success' || res.code === 200) {
      return {
        result: res.result,
        data: res.data,
        count: res.count,
        msg: res.msg,
        code: 200
      }
  }
  else {
      return {
        result: res.result,
        data: [],
        count: 0,
        msg: res.msg,
        code: 500
      };
  }
};

axios.interceptors.response.use(
  response => {
    if (
      response.status === 401 &&
      response.data &&
      response.data.data &&
      response.data.data.match(/^http/)
    ) {
      const href = encodeURIComponent(window.location.href);
      window.location.href = `${response.data.data}?redirectUrl=${href}`;
    }
    return parseData(response.data);
  },
  error => {
    //
  },
);

const request = async config => {
  config.method = config.method || 'POST';
  config.headers = config.headers || {};
  if (config.type === 'json') {
    config.headers['Content-Type'] = 'application/json;charset=UTF-8';
  } else {
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded';
  }

  try {
    if (config.body) {
      if(config.method === 'GET' && Object.keys(config.body).length) {
        config.url = `${config.url}?${qs.stringify(config.body)}`;
      }
      else if (
        isObject(config.body) &&
        !Array.isArray(config.body) &&
        config.headers &&
        config.headers['Content-Type'] &&
        config.headers['Content-Type'].indexOf('application/x-www-form-urlencoded') >= 0
      ) {
        config.body = qs.stringify(config.body);
      }
      config.body = trimParams(config.body);
    }

    return await axios({
      ...config,
      data: config.body,
      validateStatus: function(status) {
        return (status >= 200 && status < 300); // default
      },
    });
  } catch (e) {
    //
  }
};

export default request;


